<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="120"/>
        <source>Deepin Movie</source>
        <translation>Deepin Movie</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>Deepin Movie est un lecteur vidéo visuellement agréable et très complet. Il prend en charge la lecture ainsi que le « streaming » de fichiers en différents formats.</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>Dossier non valide</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open folder</source>
        <translation>Ouvrir un dossier</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Vous n&apos;avez pas la permission d&apos;agir sur ce dossier</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>Ajouter automatiquement des fichiers similaires à la liste de lecture</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>Vider la liste de lecture en quittant</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>Prévisualiser au passage de la souris</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>Ouvrir un nouveau lecteur pour chaque fichier joué</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>Mettre en pause lorsque réduit</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>Mémoriser la position de lecture</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>Chemin</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>Simple</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>Raccourcis </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>Image/Son</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>Sous-titre</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>Style de police</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>Restaurer les valeurs par défaut</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>Ouvrir le fichier</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>Ouvrir suivant</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>Ouvrir précédent</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>Mode minimal</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>Muet</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>Next frame</source>
        <translation>Image suivante</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Previous frame</source>
        <translation>Image précédente </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>Volume down</source>
        <translation>Diminuer le volume</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Volume up</source>
        <translation>Augmenter le volume</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Speed up</source>
        <translation>Accélerer</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Speed down</source>
        <translation>Ralentir</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Pause/Play</source>
        <translation>Pause/Lecture</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Playlist</source>
        <translation>Liste de lecture</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Reset speed</source>
        <translation>Réinitialiser la vitesse</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Rewind</source>
        <translation>Reculer</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Forward</source>
        <translation>Avancer</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>Burst screenshot</source>
        <translation>Capture d&apos;écran en rafale</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>Film screenshot</source>
        <translation>Capture d&apos;écran du film</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>0.5s backward</source>
        <translation>0,5 s en arrière</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>0.5s forward</source>
        <translation>0,5 s en avant</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="45"/>
        <source>Font</source>
        <translation>Police</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="46"/>
        <source>Font Size</source>
        <translation>Taille de police</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>Veuillez entrer l&apos;URL :</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="269"/>
        <source>Settings</source>
        <translation>Paramètres </translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>Toujours au premier plan</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="284"/>
        <source>Film info</source>
        <translation>Infos du film</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open file</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open folder</source>
        <translation>Ouvrir un dossier</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light theme</source>
        <translation>Thème clair</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>Ouvrir un lien</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>Ouvrir un CD/DVD</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>Mode miniature</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>Mode de lecture</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>Ordre de lecture</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>Lecture aléatoire</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>Lecture seule</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>Répéter le morceau</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>Répéter la liste</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>Dans le sens horaire</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>Sens antihoraire</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="144"/>
        <source>Next frame</source>
        <translation>Image suivante</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="145"/>
        <source>Previous frame</source>
        <translation>Image précédente </translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="152"/>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="158"/>
        <source>Stereo</source>
        <translation>Stéréo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="159"/>
        <source>Left channel</source>
        <translation>Canal gauche</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="160"/>
        <source>Right channel</source>
        <translation>Canal droit</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="166"/>
        <source>Track</source>
        <translation>Piste</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="176"/>
        <source>Subtitle</source>
        <translation>Sous-titre</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="177"/>
        <source>Load</source>
        <translation>Charger</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Online Search</source>
        <translation>Recherche en ligne</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Select</source>
        <translation>Choisir</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Hide</source>
        <translation>Cacher</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="190"/>
        <source>Encodings</source>
        <translation>Encodages</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="258"/>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="259"/>
        <source>Film Screenshot</source>
        <translation>Capture d&apos;écran du film</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="260"/>
        <source>Burst Shooting</source>
        <translation>Mode rafale</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="267"/>
        <source>Playlist</source>
        <translation>Liste de lecture</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="268"/>
        <source>Film Info</source>
        <translation>Infos du film</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="282"/>
        <source>Clear playlist</source>
        <translation>Vider la liste de lecture</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="283"/>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichiers</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>Duration: %1</source>
        <translation>Durée : %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>Resolution: %1</source>
        <translation>Résolution : %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>Size: %1</source>
        <translation>Taille : %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="720"/>
        <location filename="../common/mainwindow.cpp" line="1821"/>
        <source>Load successfully</source>
        <translation>Chargement réussi</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="720"/>
        <location filename="../common/mainwindow.cpp" line="1821"/>
        <source>Load failed</source>
        <translation>Échec du chargement</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1424"/>
        <source>No device found</source>
        <translation>Aucun périphérique trouvé</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1442"/>
        <source>Parse Failed</source>
        <translation>Échec de l&apos;analyse</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1449"/>
        <source>Open folder</source>
        <translation>Ouvrir un dossier</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1464"/>
        <location filename="../common/mainwindow.cpp" line="1481"/>
        <location filename="../common/mainwindow.cpp" line="1816"/>
        <source>Open file</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1466"/>
        <location filename="../common/mainwindow.cpp" line="1483"/>
        <source>All videos (%1)</source>
        <translation>Toutes les vidéos (%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <source>Muted</source>
        <translation>Sourdine</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1687"/>
        <location filename="../common/mainwindow.cpp" line="1699"/>
        <location filename="../common/mainwindow.cpp" line="1709"/>
        <location filename="../common/mainwindow.cpp" line="1716"/>
        <source>Volume: %1%</source>
        <translation>Volume : %1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1781"/>
        <location filename="../common/mainwindow.cpp" line="1789"/>
        <source>Subtitle %1: %2s</source>
        <translation>Sous-titre %1 : %2s</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1782"/>
        <location filename="../common/mainwindow.cpp" line="1790"/>
        <source>delayed</source>
        <translation>Retardé</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1782"/>
        <location filename="../common/mainwindow.cpp" line="1790"/>
        <source>advanced</source>
        <translation>avancé</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1797"/>
        <location filename="../common/mainwindow.cpp" line="1804"/>
        <location filename="../common/mainwindow.cpp" line="1811"/>
        <source>Speed: %1x</source>
        <translation>Vitesse : %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1818"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <translation>Sous-titres (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1880"/>
        <source>View</source>
        <translation>Vue</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1891"/>
        <source>Movie Screenshot</source>
        <translation>Capture d&apos;écran du film</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1892"/>
        <source>Saved to</source>
        <translation>Sauvegardé dans</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1906"/>
        <location filename="../common/mainwindow.cpp" line="1989"/>
        <source>The screenshot is saved</source>
        <translation>Capture d&apos;écran enregistrée</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1906"/>
        <source>Failed to save the screenshot</source>
        <translation>Échec de la sauvegarde de la capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2076"/>
        <location filename="../common/mainwindow.cpp" line="2782"/>
        <source>Invalid file: %1</source>
        <translation>Fichier non valide : %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <location filename="../libdmr/playlist_model.h" line="67"/>
        <source>%1G</source>
        <translation>%1 GO</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="69"/>
        <source>%1M</source>
        <translation>%1 MO</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="71"/>
        <source>%1K</source>
        <translation>%1 KO</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="73"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>Type de fichier :</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>Résolution :</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>Taille du fichier :</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>Durée :</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>Emplacement du fichier :</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1034"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1052"/>
        <source>[internal]</source>
        <translation>[interne]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>Le fichier n&apos;existe pas</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DMovie%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DMovie%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>Sous-titres</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>Liste de lecture</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>Lecture / Pause</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>Quitter le mode plein écran</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
</context>
</TS>